summaryrefslogtreecommitdiffstats
path: root/src/base/AnalysisTypes.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/base/AnalysisTypes.cpp')
-rw-r--r--src/base/AnalysisTypes.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/base/AnalysisTypes.cpp b/src/base/AnalysisTypes.cpp
index b2d8727..a07fd96 100644
--- a/src/base/AnalysisTypes.cpp
+++ b/src/base/AnalysisTypes.cpp
@@ -109,7 +109,7 @@ AnalysisHelper::labelChords(CompositionTimeSliceAdapter &c, Segment &s,
if ((*i)->isa(Note::EventType)) {
int bass = 999;
- int mask = 0;
+ int tqmask = 0;
GlobalChord chord(c, i, quantizer);
if (chord.size() == 0) continue;
@@ -121,15 +121,15 @@ AnalysisHelper::labelChords(CompositionTimeSliceAdapter &c, Segment &s,
assert(bass == 999); // should be in ascending order already
bass = pitch;
}
- mask |= 1 << (pitch % 12);
+ tqmask |= 1 << (pitch % 12);
}
}
i = chord.getFinalElement();
- if (mask == 0) continue;
+ if (tqmask == 0) continue;
- ChordLabel ch(key, mask, bass);
+ ChordLabel ch(key, tqmask, bass);
if (ch.isValid())
{
@@ -154,15 +154,15 @@ ChordLabel::ChordLabel()
checkMap();
}
-ChordLabel::ChordLabel(Key key, int mask, int /* bass */) :
+ChordLabel::ChordLabel(Key key, int tqmask, int /* bass */) :
m_data()
{
checkMap();
// Look for a chord built on an unaltered scale step of the current key.
- for (ChordMap::iterator i = m_chordMap.find(mask);
- i != m_chordMap.end() && i->first==mask; ++i)
+ for (ChordMap::iterator i = m_chordMap.find(tqmask);
+ i != m_chordMap.end() && i->first==tqmask; ++i)
{
if (Pitch(i->second.m_rootPitch).isDiatonicInKey(key))
@@ -233,8 +233,8 @@ ChordLabel::checkMap()
// What the basicChordMasks mean: each bit set in each one represents
// a pitch class (pitch%12) in a chord. C major has three pitch
// classes, C, E, and G natural; if you take the MIDI pitches
// of those notes modulo 12, you get 0, 4, and 7, so the mask for
// major triads is (1<<0)+(1<<4)+(1<<7). All the masks are for chords
// built on C.
const int basicChordMasks[8] =
@@ -249,8 +249,8 @@ ChordLabel::checkMap()
1 + (1<<3) + (1<<6) + (1<<9) // diminished 7th
};
// Each mask is inserted into the map rotated twelve ways; each
// rotation is a mask you would get by transposing the chord
// to have a new root (i.e., C, C#, D, D#, E, F...)
for (int i = 0; i < 8; ++i)
@@ -233,8 +233,8 @@ ChordLabel::checkMap()
// a pitch class (pitch%12) in a chord. C major has three pitch
// classes, C, E, and G natural; if you take the MIDI pitches
- // of those notes modulo 12, you get 0, 4, and 7, so the mask for
- // major triads is (1<<0)+(1<<4)+(1<<7). All the masks are for chords
+ // of those notes modulo 12, you get 0, 4, and 7, so the tqmask for
+ // major triads is (1<<0)+(1<<4)+(1<<7). All the tqmasks are for chords
// built on C.
const int basicChordMasks[8] =
@@ -249,8 +249,8 @@ ChordLabel::checkMap()
1 + (1<<3) + (1<<6) + (1<<9) // diminished 7th
};
- // Each mask is inserted into the map rotated twelve ways; each
- // rotation is a mask you would get by transposing the chord
+ // Each tqmask is inserted into the map rotated twelve ways; each
+ // rotation is a tqmask you would get by transposing the chord
// to have a new root (i.e., C, C#, D, D#, E, F...)
for (int i = 0; i < 8; ++i)